@@ -3,34 +3,24 @@ package Weather::Com::AirPressure;
 use 5.006;
 use strict;
 use warnings;
-use Weather::Com::L10N;
-use base 'Weather::Com::Object';
+use Class::Struct;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.9 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)/g;
 
 #------------------------------------------------------------------------
-# Constructor
+# The pressure class will not be a Weather::Cached class by itself,
+# because then it would not be easy to now whether it is current
+# conditions pressure or forecast pressure and if forecast pressure,
+# then of which day, etc.
+#
+# Weather::Com::AirPressure consists almost only of pure data and no
+# significant logic has to be build in. Therefore, we simply use a
+# Class::Struct subclass.
 #------------------------------------------------------------------------
-sub new {
-	my $proto = shift;
-	my $class = ref($proto) || $proto;
-	my %parameters;
-
-	# parameters provided by new method
-	if ( ref( $_[0] ) eq "HASH" ) {
-		%parameters = %{ $_[0] };
-	} else {
-		%parameters = @_;
-	}
-
-	my $self = $class->SUPER::new( \%parameters );
-
-	# getting first weather information
-	$self->{PRESSURE} = -1;
-	$self->{TENDENCY} = 'unknown';
-
-	return $self;
-}    # end new()
+struct(
+		pressure => '$',
+		tendency => '$',    
+);
 
 #------------------------------------------------------------------------
 # update barometric data
@@ -46,34 +36,16 @@ sub update {
 	}
 
 	unless ( $bar{r} ) {
-		$self->{PRESSURE} = -1;
+		$self->pressure(-1);
+		$self->tendency("unknown");
 	} else {
-		$self->{PRESSURE} = lc( $bar{r} );
-	}
-	unless ( $bar{d} ) {
-		$self->{TENDENCY} = "unknown";
-	} else {
-		$self->{TENDENCY} = lc( $bar{d} );
+		$self->pressure($bar{r});
+		$self->tendency($bar{t});
 	}
 
 	return 1;
 }
 
-#------------------------------------------------------------------------
-# access moon data
-#------------------------------------------------------------------------
-sub pressure {
-	my $self = shift;
-	return $self->{PRESSURE};
-}
-
-sub tendency {
-	my $self     = shift;
-	my $language = shift;
-
-	return $self->get_language_handle($language)->maketext(lc($self->{TENDENCY}) );
-}
-
 1;
 
 __END__
@@ -129,19 +101,17 @@ of one current conditions or forecast object.
 
 Returns the barometric pressure.
 
-=head2 tendency([$language])
+=head2 tendency()
 
 Returns the tendency of the barometric pressure.
 
-This attribute is I<dynamic language enabled>.
-
 =head1 AUTHOR
 
 Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2005 by Thomas Schnuecker
+Copyright (C) 2004 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
