@@ -10,24 +10,18 @@ use HTTP::Request;
 use XML::Simple;
 use Data::Dumper;
 use Time::Local;
-use base qw(Weather::Com::Object Exporter);
 
-#--------------------------------------------------------------------
-# Define some globals
-#--------------------------------------------------------------------
-our @EXPORT_OK = qw( 
-	celsius2fahrenheit 
-	fahrenheit2celsius 
-	convert_winddirection
-);
+use base qw(Exporter);
+our @EXPORT_OK =
+  qw ( celsius2fahrenheit fahrenheit2celsius convert_winddirection);
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.1 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)/g;
 
 my $CITY_SEARCH_URI    = "http://xoap.weather.com/search/search?where=";
 my $WEATHER_SEARCH_URI = "http://xoap.weather.com/weather/local/";
 
 my %winddir = (
-				"none"            => "none",
+				"none"			  => "none",
 				'N/A'             => "Not Available",
 				"VAR"             => "Variable",
 				"N"               => "North",
@@ -72,17 +66,7 @@ my %winddir = (
 sub new {
 	my $proto = shift;
 	my $class = ref($proto) || $proto;
-	my %parameters;
-	
-	# parameters provided by new method
-	if ( ref( $_[0] ) eq "HASH" ) {
-		%parameters = %{ $_[0] };
-	} else {
-		%parameters = @_;
-	}
-
-	# get SUPER instance
-	my $self = $class->SUPER::new( \%parameters );
+	my $self  = {};
 
 	# some general attributes
 	$self->{PROXY}   = "none";
@@ -97,12 +81,23 @@ sub new {
 	$self->{UNITS}    = 'm';    # could be 'm' for metric or 's' for us standard
 	$self->{CC}       = 0;      # show current conditions true/false
 	$self->{FORECAST} = 0;      # multi day forecast 0 = no, 1..10 days
+	$self->{LINKS}    = 0;
+
+	# parameters provided by new method
+	my %parameters = ();
+	if ( ref( $_[0] ) eq "HASH" ) {
+		%parameters = %{ $_[0] };
+	} else {
+		%parameters = @_;
+	}
 
-	# save params for further use
 	$self->{ARGS} = \%parameters;
 
+	# bless out object
+	bless( $self, $class );
+
 	# do some initialization with validity checking
-	$self = $self->_init();
+	$self = $self->_init( \%parameters );
 
 	# and some debugging output
 	$self->_debug( "Returning object: " . Dumper($self) );
@@ -134,7 +129,7 @@ sub _init {
 
 	# set timeout if it is a possitive integer or 0
 	if ( $params->{timeout} ) {
-		unless (    ( $params->{timeout} =~ /^\d+$/ )
+		unless (    ( $params->{timout} =~ /^\d+$/ )
 				 && ( $params->{timeout} > -1 ) )
 		{
 			die ref($self)
@@ -168,12 +163,7 @@ sub _init {
 	$self->{LICENSE_KEY} = $params->{license} if ( $params->{license} );
 	$self->{DEBUG}       = $params->{debug}   if ( $params->{debug} );
 	$self->{CC}          = $params->{current} if ( $params->{current} );
-
-	if ( $params->{lang} ) {
-		$self->{LANGUAGE} = $params->{lang};
-	} else {
-		$self->{LANGUAGE} = 'en_US';
-	}
+	$self->{LINKS}       = $params->{links}   if ( $params->{links} );
 
 	return $self;
 }
@@ -193,7 +183,7 @@ sub search {
 	# build up HTTP GET request
 	$place = uri_escape($place);
 	my $searchlocation = $CITY_SEARCH_URI . $place;
-	# $searchlocation .= '&prod=xoap';
+	$searchlocation .= '&prod=xoap';
 	if ( $self->{PARTNER_ID} && $self->{LICENSE_KEY} ) {
 		$searchlocation .= '&par=' . $self->{PARTNER_ID};
 		$searchlocation .= '&key=' . $self->{LICENSE_KEY};
@@ -229,7 +219,7 @@ sub search {
 
 	# XML::Simple behaves differently when one location is return than
 	# when more locations are returned ...
-	my $locations = undef;
+	my $locations = {};
 	if ( $simpleHash->{loc}->{content} ) {
 		$locations->{ $simpleHash->{loc}->{id} } =
 		  $simpleHash->{loc}->{content};
@@ -267,9 +257,9 @@ sub get_weather {
 	if ( $self->{FORECAST} ) {
 		$searchlocation .= '&dayf=' . $self->{FORECAST};
 	}
-
-	# add 'link' parameter in any case
-	$searchlocation .= '&link=xoap';
+	if ( $self->{LINKS} ) {
+		$searchlocation .= '&link=xoap';
+	}
 
 	# get weather data
 	$self->_debug($searchlocation);
@@ -281,18 +271,13 @@ sub get_weather {
 	}
 
 	# parse weather data
-	my %options = (
-					ForceArray => ["day"],    
-	);
-	my $simpleHash = XMLin($weatherXML, %options);
+	my $simpleHash = XMLin($weatherXML);
 
 	# do some error handling if weather.com returns an error message
 	if ( $simpleHash->{err} ) {
 		die ref($self), ": ERROR ", $simpleHash->{err}->{content}, "\n";
 	}
 
-	$self->_debug(Dumper($simpleHash));
-
 	return $simpleHash;
 }
 
@@ -422,13 +407,13 @@ sub _epoc2lsup {
 
 sub _simple2twentyfour {
 	my $stime   = shift;
-	my $colon   = index( $stime, ":" );
+	my $colon   = index($stime, ":");
 	my $hour    = substr( $stime, 0, $colon );
 	my $minutes = substr( $stime, $colon + 1, 2 );
 	my $ampm    = substr( $stime, 6 );
 
 	if ( lc($ampm) =~ /PM/ ) {
-		return $hour + 12 . ":" . $minutes;
+		return $hour + 12 . ":" . $minutes;    
 	} else {
 		return "$hour:$minutes";
 	}
@@ -460,6 +445,7 @@ Weather::Com::Base - Perl extension for getting weather information from weather
   my %params = (
 		'current'    => 1,
 		'forecast'   => 3,
+		'links'      => 1,
 		'units'      => 's',
 		'proxy'      => 'http://proxy.sonstwo.de',
 		'timeout'    => 250,
@@ -568,6 +554,11 @@ set to any other value, this is interpreted as 0!
 
 Defaults to 0 (false).
 
+=item links => 0 | 1
+
+This parameter specifies whether to load some http links from I<weather.com>
+also or not.
+
 =item units => s | m
 
 This parameter defines whether to fetch information in metric (m) or 
@@ -721,6 +712,10 @@ I<weather.com>. The parts of the hashref are explained afterwards.
 	'dayf' => {
 		'lsup' => '8/16/04 12:17 PM Local Time',
 		'day'  => [	
+						# ATTENTION: This is only an array of hashes if
+						# there is more than 1 day forecasted. If only
+						# a 1 day forecast is requested, there's only a
+						# single hash. No array.
 			{
 				'hi'   => '27',
 				'suns' => '8:40 PM',
@@ -1041,7 +1036,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2009 by Thomas Schnuecker
+Copyright (C) 2004 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
