@@ -4,14 +4,11 @@ use 5.006;
 use strict;
 use warnings;
 use Weather::Com::AirPressure;
-use Weather::Com::DateTime;
-use Weather::Com::Moon;
 use Weather::Com::UVIndex;
 use Weather::Com::Wind;
-use Weather::Com::L10N;
 use base "Weather::Com::Cached";
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.13 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)/g;
 
 #------------------------------------------------------------------------
 # Constructor
@@ -43,15 +40,10 @@ sub new {
 	$self->{ID} = $parameters{location_id};
 
 	# getting first weather information
-	$self->{BAR}             = undef;
-	$self->{UV}              = undef;
-	$self->{MOON}            = undef;
-	$self->{WEATHER}         = $self->get_weather( $self->{ID} );
-	$self->{WIND}            = undef;
-	$self->{LAST_XML_UPDATE} = undef;
-
-	# remember instantiation time (and later last update time)
-	$self->{LSUP} = time();
+	$self->{WEATHER} = $self->get_weather( $self->{ID} );
+	$self->{WIND}    = undef;
+	$self->{BAR}     = undef;
+	$self->{UV}      = undef;
 
 	return $self;
 }    # end new()
@@ -61,13 +53,7 @@ sub new {
 #------------------------------------------------------------------------
 sub refresh {
 	my $self = shift;
-	my $now  = time();
-
-	# only refresh if last update has been more than 15 min ago
-	if ( ( $now - $self->{LSUP} ) > 900 ) {
-		$self->{WEATHER} = $self->get_weather( $self->{ID} );
-		$self->{LSUP}    = $now;
-	}
+	$self->{WEATHER} = $self->get_weather( $self->{ID} );
 	return 1;
 }
 
@@ -90,90 +76,12 @@ sub icon {
 	return $self->{WEATHER}->{cc}->{icon};
 }
 
-sub description {
-	my $self     = shift;
-	my $language = shift;
-
-	$self->refresh();
-	return $self->get_language_handle($language)
-	  ->maketext( lc( $self->{WEATHER}->{cc}->{t} ) );
-
-}
-
-sub temperature {
-	my $self = shift;
-	$self->refresh();
-	return $self->{WEATHER}->{cc}->{tmp};
-}
-
 sub windchill {
 	my $self = shift;
 	$self->refresh();
 	return $self->{WEATHER}->{cc}->{flik};
 }
 
-sub humidity {
-	my $self = shift;
-	$self->refresh();
-	return $self->{WEATHER}->{cc}->{hmid};
-}
-
-sub pressure {
-	my $self = shift;
-	$self->refresh();
-
-	unless ( $self->{BAR} ) {
-		$self->{BAR} = Weather::Com::AirPressure->new( $self->{ARGS} );
-	}
-	$self->{BAR}->update( $self->{WEATHER}->{cc}->{bar} );
-	return $self->{BAR};
-}
-
-sub dewpoint {
-	my $self = shift;
-	$self->refresh();
-	return $self->{WEATHER}->{cc}->{dewp};
-}
-
-sub moon {
-	my $self = shift;
-	$self->refresh();
-
-	unless ( $self->{MOON} ) {
-		$self->{MOON} = Weather::Com::Moon->new( $self->{ARGS} );
-	}
-	$self->{MOON}->update( $self->{WEATHER}->{cc}->{moon} );
-	return $self->{MOON};
-}
-
-sub uv_index {
-	my $self = shift;
-	$self->refresh();
-
-	unless ( $self->{UV} ) {
-		$self->{UV} = Weather::Com::UVIndex->new( $self->{ARGS} );
-	}
-	$self->{UV}->update( $self->{WEATHER}->{cc}->{uv} );
-	return $self->{UV};
-}
-
-sub visibility {
-	my $self = shift;
-	$self->refresh();
-	return $self->{WEATHER}->{cc}->{vis};
-}
-
-sub wind {
-	my $self = shift;
-	$self->refresh();
-
-	unless ( $self->{WIND} ) {
-		$self->{WIND} = Weather::Com::Wind->new( $self->{ARGS} );
-	}
-	$self->{WIND}->update( $self->{WEATHER}->{cc}->{wind} );
-	return $self->{WIND};
-}
-
 sub observatory {
 	my $self = shift;
 	$self->refresh();
@@ -183,14 +91,70 @@ sub observatory {
 sub last_updated {
 	my $self = shift;
 	$self->refresh();
+	return $self->{WEATHER}->{cc}->{lsup};
+}
 
-	unless ( $self->{LAST_XML_UPDATE} ) {
-		$self->{LAST_XML_UPDATE} =
-		  Weather::Com::DateTime->new( $self->{ARGS}->{zone} );
+sub temperature {
+	my $self = shift;
+	$self->refresh();
+	return $self->{WEATHER}->{cc}->{tmp};
+}
+
+sub humidity {
+	my $self = shift;
+	$self->refresh();
+	return $self->{WEATHER}->{cc}->{hmid};
+}
+
+sub wind {
+	my $self = shift;
+	$self->refresh();
+
+	unless ( $self->{WIND} ) {
+		$self->{WIND} = Weather::Com::Wind->new();
 	}
+	$self->{WIND}->update( $self->{WEATHER}->{cc}->{wind} );
+	return $self->{WIND};
+}
 
-	$self->{LAST_XML_UPDATE}->set_lsup( $self->{WEATHER}->{cc}->{lsup} );
-	return $self->{LAST_XML_UPDATE};
+sub pressure {
+	my $self = shift;
+	$self->refresh();
+
+	unless ( $self->{BAR} ) {
+		$self->{BAR} = Weather::Com::AirPressure->new();
+	}
+	$self->{BAR}->update( $self->{WEATHER}->{cc}->{bar} );    
+	return $self->{BAR};
+}
+
+sub dewpoint {
+	my $self = shift;
+	$self->refresh();
+	return $self->{WEATHER}->{cc}->{dewp};
+}
+
+sub uv_index {
+	my $self = shift;
+	$self->refresh();
+
+	unless ( $self->{UV} ) {
+		$self->{UV} = Weather::Com::UVIndex->new();
+	}
+	$self->{UV}->update( $self->{WEATHER}->{cc}->{uv} );
+	return $self->{UV};
+}
+
+sub visibility {
+	my $self = shift;
+	$self->refresh();
+	return $self->{WEATHER}->{cc}->{vis};
+}
+
+sub description {
+	my $self = shift;
+	$self->refresh();
+	return $self->{WEATHER}->{cc}->{t};
 }
 
 1;
@@ -215,7 +179,6 @@ Weather::Com::CurrentConditions - class containing current weather conditions
   my %weatherargs = (
 	'partner_id' => $PartnerId,
 	'license'    => $LicenseKey,
-	'language'   => 'de',
   );
 
   my $finder = Weather::Com::Finder->new(%weatherargs);
@@ -265,15 +228,10 @@ Returns the location id used to instantiate this object.
 
 Returns the name of the location this current conditions belong to.
 
-=head2 description([$language])
+=head2 description()
 
 Returns a textual representation of the current weather conditions.
 
-This description is translated if you specified the I<language> option
-as argument for your I<Weather::Com::Finder>.
-
-This attribute is I<dynamic language enabled>.
-
 =head2 dewpoint() 
 
 Returns the dewpoint.
@@ -291,8 +249,10 @@ after you've registered to get your license.
 
 =head2 last_updated()
 
-Returns a I<Weather::Com::DateTime> object containing the date and
-time of the last update as provided by I<weather.com>.
+Returns the C<lsup> string as provided by I<weather.com>.
+
+This may change in the future to provide a more sensible
+time and date format...
 
 =head2 observatory()
 
@@ -348,7 +308,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2005 by Thomas Schnuecker
+Copyright (C) 2004 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
