@@ -5,11 +5,9 @@ use strict;
 use warnings;
 use Carp;
 use Data::Dumper;
-use Weather::Com::Cached;
+use Weather::Com::Base;
 use Weather::Com::Location;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.8 $ =~ /(\d+)/g;
-
 #------------------------------------------------------------------------
 # Constructor
 #------------------------------------------------------------------------
@@ -29,7 +27,7 @@ sub new {
 	# god, bless the object
 	$self = bless( $self, $class );
 
-	# Weather::Com::Cached object for searching
+	# Weather::Com::Base object for searching
 	my %weatherargs = ();
 	
 	# define proxy args
@@ -47,11 +45,10 @@ sub new {
 	$weatherargs{partner_id} = $parameters{partner_id}
 	  if ( $parameters{partner_id} );
 	$weatherargs{license} = $parameters{license} if ( $parameters{license} );
-	$weatherargs{language} = $parameters{language} if ( $parameters{language} );	
 
 	# initialize weather object
 	$self->{ARGS}    = \%weatherargs;
-	$self->{WEATHER} = Weather::Com::Cached->new(%weatherargs);
+	$self->{WEATHER} = Weather::Com::Base->new(%weatherargs);
 
 	return $self;
 }    # end new()
@@ -75,7 +72,6 @@ sub find {
 	foreach ( keys %{$loc_weather} ) {
 		my %weatherargs = %{ $self->{ARGS} };
 		$weatherargs{location_id} = $_;
-		$weatherargs{location_name} = $loc_weather->{$_};
 		
 		my $location = Weather::Com::Location->new(%weatherargs);
 		push( @locations, $location );
@@ -187,7 +183,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2007 by Thomas Schnuecker
+Copyright (C) 2004 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
