@@ -3,15 +3,15 @@ package Weather::Com::Location;
 use 5.006;
 use strict;
 use warnings;
-use Carp;
 use Time::Local;
 use Weather::Com::Cached;
 use Weather::Com::Units;
 use Weather::Com::CurrentConditions;
-use Weather::Com::Forecast;
+
+#use Weather::Com::Forecast;
 use base "Weather::Com::Cached";
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.9 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)/g;
 
 #------------------------------------------------------------------------
 # Constructor
@@ -42,7 +42,7 @@ sub new {
 	my $self = $class->SUPER::new( \%parameters );
 
 	$self->{ID}    = $parameters{location_id};
-	$self->{NAME}  = $parameters{location_name};
+	$self->{ARGS}  = \%parameters;
 	$self->{DEBUG} = $parameters{debug};
 
 	# the weather data will be initialized when the first call on
@@ -51,9 +51,6 @@ sub new {
 	$self->{WEATHER}    = undef;
 	$self->{CONDITIONS} = undef;
 	$self->{FORECAST}   = undef;
-	$self->{LOCALTIME}  = undef;
-	$self->{SUNRISE}    = undef;
-	$self->{SUNSET}     = undef;
 
 	# last update will be used to trigger automatic refresh of
 	# location data
@@ -61,9 +58,6 @@ sub new {
 
 	bless( $self, $class );
 
-	# init object, add timezone to ARGS
-	$self->{ARGS}->{lang} = $parameters{language} || 'en';
-
 	return $self;
 }    # end new()
 
@@ -73,9 +67,10 @@ sub new {
 # this calls refresh if weather data is not initialized yet
 sub refresh {
 	my $self = shift;
-	if ( !$self->{WEATHER} || $self->_update ) {
+	unless ( $self->{WEATHER} ) {
+		$self->_debug("Refreshing weather information...");
 		$self->{WEATHER} = $self->get_weather( $self->{ID} );
-		$self->_debug("Weather data refreshed!");
+		$self->{LSUP}    = time();
 	}
 	return 1;
 }
@@ -90,7 +85,8 @@ sub id {
 
 sub name {
 	my $self = shift;
-	return $self->{NAME};
+	$self->refresh();
+	return $self->{WEATHER}->{loc}->{dnam};
 }
 
 sub units {
@@ -100,18 +96,14 @@ sub units {
 	unless ( $self->{HEAD} ) {
 		$self->{HEAD} = Weather::Com::Units->new();
 	}
-	$self->{HEAD}->update( $self->{WEATHER}->{head} );
+	$self->{HEAD}->update( $self->{WEATHER}->{head} );	
 	return $self->{HEAD};
 }
 
 sub timezone {
 	my $self = shift;
-
-	unless ( $self->{WEATHER} ) {
-		$self->{WEATHER} = $self->get_weather( $self->{ID} );
-	}
-	$self->{ARGS}->{zone} = $self->{WEATHER}->{loc}->{zone};
-	return $self->{ARGS}->{zone};
+	$self->refresh();
+	return $self->{WEATHER}->{loc}->{zone};
 }
 
 sub latitude {
@@ -126,78 +118,62 @@ sub longitude {
 	return $self->{WEATHER}->{loc}->{lon};
 }
 
-# localtime will be calculated because it does not make
-# any sense to used a cached time as current local time of
-# some location
-sub localtime {
-	my $self = shift;
-	$self->refresh();
-
-	unless ( $self->{LOCALTIME} ) {
-		$self->{LOCALTIME} = Weather::Com::DateTime->new( $self->timezone() );
-	}
-
-	return $self->{LOCALTIME};
-}
-
-sub localtime_ampm {
-	carp("Use of deprecated method 'localtime_ampm()'!");
-	carp("Please use 'localtime()->time_ampm()' instead.");
-
-	my $self = shift;
-	$self->refresh();
-
-	return $self->localtime()->time_ampm();
-}
-
 sub sunrise {
 	my $self = shift;
 	$self->refresh();
-
-	unless ( $self->{SUNRISE} ) {
-		$self->{SUNRISE} = Weather::Com::DateTime->new( $self->timezone() );
-	}
-
-	$self->{SUNRISE}->set_time( $self->{WEATHER}->{loc}->{sunr} );
-	return $self->{SUNRISE};
+	$self->_update();
+	my $sunr = $self->{WEATHER}->{loc}->{sunr};
+	return &Weather::Com::Base::_simple2twentyfour($sunr);
 }
 
 sub sunrise_ampm {
-	carp("Use of deprecated method 'sunrise_ampm()'!");
-	carp("Please use 'sunrise()->time_ampm()' instead.");
-
 	my $self = shift;
 	$self->refresh();
-
-	return $self->sunrise()->time_ampm();
+	$self->_update();
+	return $self->{WEATHER}->{loc}->{sunr};
 }
 
 sub sunset {
 	my $self = shift;
 	$self->refresh();
-
-	unless ( $self->{SUNSET} ) {
-		$self->{SUNSET} = Weather::Com::DateTime->new( $self->timezone() );
-	}
-
-	$self->{SUNSET}->set_time( $self->{WEATHER}->{loc}->{suns} );
-	return $self->{SUNSET};
+	$self->_update();
+	my $suns = $self->{WEATHER}->{loc}->{suns};
+	return &Weather::Com::Base::_simple2twentyfour($suns);
 }
 
 sub sunset_ampm {
-	carp("Use of deprecated method 'sunset_ampm()'!");
-	carp("Please use 'sunset()->time_ampm()' instead.");
-
 	my $self = shift;
 	$self->refresh();
+	$self->_update();
+	return $self->{WEATHER}->{loc}->{suns};
+}
 
-	return $self->sunset()->time_ampm();
+# localtime will be calculated because it does not make
+# any sense to used a cached time as current local time of
+# some location
+sub localtime {
+	my $self = shift;
+	my @gm   = gmtime( $self->_local_epoc( time() ) );
+	return "$gm[2]:$gm[1]";
+}
+
+sub localtime_ampm {
+	my $self = shift;
+	my @gm   = gmtime( $self->_local_epoc( time() ) );
+	my $ampm = "AM";
+
+	# and we have to find out weather we wanna print AM or PM
+	# and then substract 12 hours if it's afternoon
+	if ( $gm[2] > 12 ) {
+		$gm[2] -= 12;
+		$ampm = "PM";
+	}
+
+	return "$gm[2]:$gm[1] $ampm";
 }
 
 sub current_conditions {
 	my $self = shift;
-	$self->refresh();
-
 	unless ( $self->{CONDITIONS} ) {
 		$self->{CONDITIONS} =
 		  Weather::Com::CurrentConditions->new( $self->{ARGS} );
@@ -207,8 +183,6 @@ sub current_conditions {
 
 sub forecast {
 	my $self = shift;
-	$self->refresh();
-
 	unless ( $self->{FORECAST} ) {
 		$self->{FORECAST} = Weather::Com::Forecast->new( $self->{ARGS} );
 	}
@@ -227,25 +201,29 @@ sub _update {
 	# 2. get 00:00:00 of today in local time of location
 	# If both in epoc are equal, no update is needed, else we'll get
 	# the new location information.
-	my @lsup = gmtime( $self->timezone() * 3600 + $self->{LSUP} );    
+	my @lsup = gmtime( $self->_local_epoc( $self->{LSUP} ) );
 	$lsup[0] = 0;
 	$lsup[1] = 0;
 	$lsup[2] = 0;
-	my $local_epoc_lsup = timegm(@lsup);
+	my $local_epoc_lsup = timelocal(@lsup);
 
 	$self->{LSUP} = time();
-	my @now = gmtime( time() + ( $self->timezone() * 3600 ) );
+	my @now = gmtime( $self->_local_epoc( $self->{LSUP} ) );
 	$now[0] = 0;
 	$now[1] = 0;
 	$now[2] = 0;
-	my $local_epoc_now = timegm(@now);
+	my $local_epoc_now = timelocal(@now);
 
 	if ( $local_epoc_now > $local_epoc_lsup ) {
-		$self->_debug("should refresh location cache...\n");
-		return 1;
+		$self->_debug("refreshing location cache...\n");
+		$self->refresh();
 	}
+}
 
-	return 0;
+sub _local_epoc {
+	my $self = shift;
+	my $time = shift;
+	return ( $time + ( $self->timezone() * 3600 ) );
 }
 
 1;
@@ -284,8 +262,8 @@ Weather::Com::Location - class representing one location and its weather
     print "Found weather for city: ", $location->name(), "\n";
     print "The city is located at: ", $location->latitude(), "deg N, ",
 		  $location->longitude(), "deg E\n";
-	print "Local time is ", $location->localtime()->time(), "\n";
-	print "Sunrise will be/has been at ", $location->sunrise()->time(), "\n";
+	print "Local time is ", $location->localtime(), "\n";
+	print "Sunrise will be/has been at ", $location->sunrise(), "\n";
     
   }
 
@@ -338,9 +316,12 @@ details.
 
 =head2 forecast() 
 
+I<not implemented yet, comming soon>
+
 Returns a I<Weather::Com::Forecast> object.
 
-Please refer to L<Weather::Com::Forecast> for further details.
+Please refer to L<Weather::Com::Forecast> for further
+details.
 
 =head2 latitude()
 
@@ -352,19 +333,25 @@ Returns the longitude of the location.
 
 =head2 localtime()
 
-Returns a Weather::Com::DateTime object containing the local time
-of the location.
+Returns the local time of the location.
 
 This value is evaluated each time you call this method. We do not use
 the value returned from I<weather.com> here because it does not make
 any sence to use a cached value to show the current time.
 
+The time is returned in the format C<hh:mm> where C<hh> is in 24 hour format.
+To get a 12 hour format use C<localtime_ampm> instead.
+
+  Sample: 14:34
+
 =head2 localtime_ampm()
 
-B<This method is deprecated and will be removed with the next release!>
-
 Returns the local time of the location.
 
+This value is evaluated each time you call this method. We do not use
+the value returned from I<weather.com> here because it does not make
+any sence to use a cached value to show the current time.
+
 The time is returned in the format C<hh:mm [AM|PM]>.
 To get a 24 hour format use C<localtime> instead.
 
@@ -372,23 +359,19 @@ To get a 24 hour format use C<localtime> instead.
 
 =head2 sunrise()
 
-Returns a Weather::Com::DateTime object containing the time of sunrise.
+Returns the time of sunrise in 24 hour format.
 
 =head2 sunrise_ampm()
 
-B<This method is deprecated and will be removed with the next release!>
-
 Returns the time of sunrise in 12 hour format (see C<localtime_ampm()>
 for details).
 
 =head2 sunset()
 
-Returns a Weather::Com::DateTime object containing the time of sunset.
+Returns the time of sunset in 24 hour format.
 
 =head2 sunset_ampm()
 
-B<This method is deprecated and will be removed with the next release!>
-
 Returns the time of sunset in 12 hour format (see C<localtime_ampm()>
 for details).
 
@@ -415,7 +398,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2005 by Thomas Schnuecker
+Copyright (C) 2004 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
